# biearce_time

A Python package that provides a static 'today' timestamp and time functions based on it.

## Usage

```
import biearce_time
print(biearce_time.now())
```

## Installation

You can install the package using pip:

```bash
pip install biearce_time
```

## License

This project is licensed under the MIT License - see the LICENSE file for details. 